% extract features -- fuzzyen
% using different window length
% batch all possible windows for all data saved in the user defined path
% NOTE that there are five categories and data have been saved to five
% subfolders named with Z, O, N, F, S within the defined path. 100 files in
% each subfolder
% 
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%                      (C) Peng Li 2017 -
% If you use the code, please make sure that you cite the paper mentioned
% where this resource is shared and this webpage
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% 
% $Author:      Peng Li
%               School of Control Science and Engineering,
%                   Shandong University, PR China
%                   Email: pli@sdu.edu.cn
% $Date:        Jul 25, 2017
% 
close all; clear; clc;

%% config
dataPath = '..\Bonn';
subFold  = {'Z', 'O', 'N', 'F', 'S'}; % normal normal interictal interictal ictal
fileNm   = 1:100;

mt   = [3 10]; % fixed m and tau
r    = 0.2;

fs   = 173.61; % sampling rate
wind = 1:23;   % window lengths from 1 to 23 sec
WDL  = floor(wind .* fs);

N    = 4097; % recording length

%% extracting and saving results
wrPath = '..\Results';
if ~(exist(wrPath, 'dir') == 7)
    mkdir(wrPath);
end
warning('off', 'MATLAB:xlswrite:AddSheet');

for iW = 1:length(WDL)
    curWindLen  = WDL(iW);
    AllPosWind  = floor((N - curWindLen) / WDL(1)) + 1;
    
    for iS      = 1:length(subFold)
        curFold = fullfile(dataPath, [subFold{iS} 'Filt']); % NOTE data were filtered and save in subfolders ZFilt, OFilt, ...
        FuzzyEnTemp  = zeros(length(fileNm), AllPosWind);
        
        for iF      = 1:length(fileNm)
            curFile = fullfile(curFold, [subFold{iS} sprintf('%03d', fileNm(iF)) '.txt']);
            eeg     = load(curFile);
            
            tic;
            for iA  = 1:AllPosWind
                eegseg = eeg((iA-1)*WDL(1)+1:(iA-1)*WDL(1)+curWindLen); % moving window with 1s overlap. easy to modify here to have 0 overlap or whatever you want
                
                FuzzyEnTemp(iF, iA) = fuzzyen(eegseg, mt(1), mt(2), r);
            end
            t = toc;
            
            disp(['Window length: ' num2str(wind(iW)) ' sec; possible window #: ' num2str(AllPosWind) '; set: ' subFold{iS} '; file: ' num2str(fileNm(iF)) '; running time: ' sprintf('%.2f', t)]);
        end
        
        % write
        xlswrite(fullfile(wrPath, ['FuzzyEn_Results_WindowLength_' num2str(wind(iW)) 'sec.xlsx']), FuzzyEnTemp, subFold{iS});
    end
end
warning('on', 'MATLAB:xlswrite:AddSheet');